@@ -158,8 +158,9 @@ def _memmap_flat(path, dtype=None, n_channels=None, offset=0, mode='r+'):
     assert n_channels > 0
     fsize = path.stat().st_size
     item_size = np.dtype(dtype).itemsize
-    assert (fsize - offset) % (item_size * n_channels) == 0,\
-        'Inconsistent number of channels between the params file and the binary dat file'
+    if (fsize - offset) % (item_size * n_channels) != 0:
+        logger.warning('Inconsistent number of channels between the '
+                       'params file and the binary dat file')
     n_samples = (fsize - offset) // (item_size * n_channels)
     shape = (n_samples, n_channels)
     return np.memmap(path, dtype=dtype, offset=offset, shape=shape, mode=mode)
